Formatting changes

[ROCm/hip commit: 55f2a38120]
Este commit está contenido en:
Rahul Garg
2019-10-30 18:12:51 -07:00
cometido por GitHub
padre 8429e15052
commit b68c8d2f60
@@ -1,5 +1,5 @@
/* /*
Copyright (c) 2019 -> Present Advanced Micro Devices, Inc. All rights reserved. Copyright (c) 2019 - present Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights in the Software without restriction, including without limitation the rights
@@ -20,24 +20,20 @@ THE SOFTWARE.
#include"hip/hip_runtime.h" #include"hip/hip_runtime.h"
extern "C" __global__ void matmulK(int* A, int* B, int* C, int N) { extern "C" __global__ void matmulK(int* A, int* B, int* C, int N) {
int ROW = blockIdx.y*blockDim.y+threadIdx.y; int ROW = blockIdx.y*blockDim.y+threadIdx.y;
int COL = blockIdx.x*blockDim.x+threadIdx.x; int COL = blockIdx.x*blockDim.x+threadIdx.x;
int tmpSum = 0; int tmpSum = 0;
if (ROW < N && COL < N) {
if (ROW < N && COL < N) { // each thread computes one element of the block sub-matrix
// each thread computes one element of the block sub-matrix for (int i = 0; i < N; i++) {
for (int i = 0; i < N; i++) { tmpSum += A[ROW * N + i] * B[i * N + COL];
tmpSum += A[ROW * N + i] * B[i * N + COL]; }
} }
} C[ROW * N + COL] =tmpSum;
C[ROW * N + COL] =tmpSum;
} }
extern "C" __global__ void WaitKernel() { extern "C" __global__ void WaitKernel() {
unsigned long long int wait_t=32000000000,start=clock64(),cur; unsigned long long int wait_t=32000000000,start=clock64(),cur;
do{cur=clock64()-start;} do{cur=clock64()-start;}
while(cur<wait_t); while(cur<wait_t);
} }